summaryrefslogtreecommitdiff
path: root/Version.hs
diff options
context:
space:
mode:
Diffstat (limited to 'Version.hs')
-rw-r--r--Version.hs6
1 files changed, 4 insertions, 2 deletions
diff --git a/Version.hs b/Version.hs
index 839470120..fc1ce3d7e 100644
--- a/Version.hs
+++ b/Version.hs
@@ -29,9 +29,11 @@ getVersion = do
then return $ Just v
else do
-- version 0 was not recorded in .git/config;
- -- such a repo should have an annexDir
+ -- such a repo should have an annexDir but no
+ -- annexObjectDir
d <- liftIO $ doesDirectoryExist $ annexDir g
- if d
+ o <- liftIO $ doesDirectoryExist $ annexObjectDir g
+ if d && not o
then return $ Just "0"
else return Nothing -- no version yet